@@ -4,16 +4,16 @@ use warnings;
 package Printer::Thermal;
 
 # PODNAME: Printer::Thermal
-# ABSTRACT: Interface for Thermal and some dot-matrix and inkjet Printers that support ESC-POS specification.
+# ABSTRACT: Interface for Thermal and some dot-matrix and inkjet Printers that support ESC-POS specification (Deprecated) - Use Printer::ESCPOS instead
 #
 # This file is part of Printer-Thermal
 #
-# This software is copyright (c) 2013 by Shantanu Bhadoria.
+# This software is copyright (c) 2015 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.27'; # VERSION
+our $VERSION = '0.28'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -761,11 +761,11 @@ __END__
 
 =head1 NAME
 
-Printer::Thermal - Interface for Thermal and some dot-matrix and inkjet Printers that support ESC-POS specification.
+Printer::Thermal - Interface for Thermal and some dot-matrix and inkjet Printers that support ESC-POS specification (Deprecated) - Use Printer::ESCPOS instead
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -801,7 +801,7 @@ version 0.27
 
 =head1 DESCRIPTION
 
-Some might not find the module name accurate since ESC-P was developed initially for dot matrix and inkjet printers, however today most Thermal Receipt Printers use these codes for control. Most people(i.e. like me when I started looking for Thermal Printer stuff) who look for Thermal Printer codes don't know Thermal Printers use certain set of ESC codes to achieve a bunch of functions, and I didn't want to name it Printer::ESC::P because that would not help people who are new to receipt printers looking for something like this module. This module provides an Object oriented interface for interacting with Thermal Printers. Maybe I will refactor it later with subclasses. I used Moose and I apologize for that!! 
+This Module is deprecated in favour of L<Printer::ESCPOS>, which is the shiny new successor to this module. L<Printer::Thermal> will continue to work and might receive occasional support and bug fixes but no new features. Read the See Also section for reasons on why I deprecated L<Printer::Thermal> in favour of a new namespace instead of upgrading the existing module. For those who are already using L<Printer::Thermal>, have simple needs and are happy with what this module provides, they can avoid the switch to L<Printer::ESCPOS> as that module does not have a interface compatible with L<Printer::Thermal> and might involve some work switching over. If you are starting a new project or if you want the support for brand new features like printing logos etc., then you must use L<Printer::ESCPOS>.
 
 For ESC-P codes refer the guide from Epson http:E<sol>E<sol>support.epson.ruE<sol>uploadE<sol>library_fileE<sol>14E<sol>esc-p.pdf
 
@@ -1086,6 +1086,30 @@ to the printer.
 
 Note: While you may call print() after every single command code, this is not advisable as some printers tend to choke up if you send them too many commands too quickly.
 
+=head1 SEE ALSO
+
+L<Printer::ESCPOS> is the new module that will take over the Perl support for ESC-POS receipt printers. Why did I choose to deprecate L<Printer::Thermal> for L<Printer::ESCPOS> instead of upgrading it? Read on if you are curious
+
+=over
+
+=item *
+
+When I started writing L<Printer::Thermal> I was working with Thermal printers for my own requirements and wanted to write something that would work with all Thermal Printers. As I discovered after a couple of releases of L<Printer::Thermal>, the ESC-POS specification is a broad command specification for POS printers and it has nothing to do with the print technology itself thermal or others, so the name of the module was a big misnomer and it led to lot of confusion as to question of what the module was actually for.
+
+=item *
+
+L<Printer::Thermal> module was only intended for supporting thermal printers but it worked quiet well with other printer types. The way receipt printers work there was no reason to have a module specifically for thermal printers. So this Printer::Thermal name started to make me uneasy.
+
+=item *
+
+There are those have minimal printing needs from their POS printers, they are already using L<Printer::Thermal> and are happy with it. There is no reason for them to switch over unless they start a new project. For newer users it makes sense to start with a module that will have future supports and adds a wider range of flexible functions for ESC-POS Printers.
+
+=item *
+
+Last but not the least important reason, I wanted to make two things user-expandable: Printer connection(USB, Serial, Network etc.) and Printer Model Profiles(As I discovered that while most printer had more or less common command codes, They all had their own feature sets which borrowed most commands from a subset of ESCPOS. So I wanted users to be able to create their own profiles of supported commands to allow community effort for expansion of module functionality. Adding these two to existing module would have broken backward compatibility. L<Printer::ESCPOS> will have better interfaces for users to add their own connection types and printer profiles.
+
+=back
+
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
@@ -1093,7 +1117,7 @@ Note: While you may call print() after every single command code, this is not ad
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through github at 
-L<https://github.com/shantanubhadoria/printer-thermal/issues>.
+L<https://github.com/shantanubhadoria/perl-printer-thermal/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -1101,9 +1125,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/shantanubhadoria/printer-thermal>
+L<https://github.com/shantanubhadoria/perl-printer-thermal>
 
-  git clone git://github.com/shantanubhadoria/printer-thermal.git
+  git clone git://github.com/shantanubhadoria/perl-printer-thermal.git
 
 =head1 AUTHOR
 
@@ -1111,11 +1135,13 @@ Shantanu Bhadoria (shantanu@cpan.org)
 
 =head1 CONTRIBUTOR
 
+=for stopwords Shantanu Bhadoria
+
 Shantanu Bhadoria <shantanu att cpan dott org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Shantanu Bhadoria.
+This software is copyright (c) 2015 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
